@@ -16,9 +16,13 @@ def profiles():
 
     demo_profiles = [
         "alita",
+        "lotr",
+        "test_noexist",
+        "test_noapps",
+        "test_badapps",
     ]
 
-    user_profiles = os.getenv("MY_PROJECTS", "").split(",")
+    user_profiles = os.getenv("MY_PROFILES", "").split(",")
 
     return user_profiles + demo_profiles
 
